@@ -1,21 +1,13 @@
 package Text::ANSITable::StyleSet::AltRow;
 
-our $DATE = '2020-06-21'; # DATE
-our $VERSION = '0.599_002'; # TRIAL VERSION
-
 use 5.010;
 use Moo;
-use namespace::clean;
 
 has odd_bgcolor  => (is => 'rw');
 has even_bgcolor => (is => 'rw');
 has odd_fgcolor  => (is => 'rw');
 has even_fgcolor => (is => 'rw');
 
-sub summary {
-    "Set different foreground and/or background color for odd/even rows";
-}
-
 sub apply {
     my ($self, $table) = @_;
 
@@ -28,12 +20,12 @@ sub apply {
                 $styles{bgcolor} = $self->odd_bgcolor
                     if defined $self->odd_bgcolor;
                 $styles{fgcolor}=$self->odd_fgcolor
-                    if defined $self->odd_fgcolor;
+                    if defined $self->odd_bgcolor;
             } else {
                 $styles{bgcolor} = $self->even_bgcolor
                     if defined $self->even_bgcolor;
                 $styles{fgcolor} = $self->even_fgcolor
-                    if defined $self->even_fgcolor;
+                    if defined $self->even_bgcolor;
             }
             \%styles;
         },
@@ -42,8 +34,6 @@ sub apply {
 
 1;
 
-# ABSTRACT: Set different foreground and/or background color for odd/even rows";
-
 __END__
 
 =pod
@@ -52,13 +42,18 @@ __END__
 
 =head1 NAME
 
-Text::ANSITable::StyleSet::AltRow - Set different foreground and/or background color for odd/even rows";
+Text::ANSITable::StyleSet::AltRow
 
 =head1 VERSION
 
-This document describes version 0.599_002 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2020-06-21.
+version 0.29
 
-=for Pod::Coverage ^(summary|apply)$
+=head1 DESCRIPTION
+
+This style set allows you to set different foreground and/or background color
+for odd/even rows.
+
+=for Pod::Coverage ^(apply)$
 
 =head1 ATTRIBUTES
 
@@ -76,7 +71,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSIT
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Text-ANSITable>.
+Source repository is at L<https://github.com/sharyanto/perl-Text-ANSITable>.
 
 =head1 BUGS
 
@@ -88,11 +83,11 @@ feature.
 
 =head1 AUTHOR
 
-perlancar <perlancar@cpan.org>
+Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
